<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<title>cv_image_suit</title>
	<!-- Mobile Specific Metas -->
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<!-- Font-->
	<link rel="stylesheet" type="text/css" href="static/css2/nunito-font.css">
	<!-- Main Style Css -->
    <link rel="stylesheet" href="static/css2/style.css"/>

</head>
<body class="form-v9">
	<div class="page-content">
		<div class="form-v9-content" style="background-image: url('static/assets/img/form-v9.jpg')">

			<form class="form-detail" action="/test" method="post">
                <h2>Already Available Model</h2>
                <center>
                    {% for e in model_list %}
                        {{e}}
                    {% endfor %}
                </center>
				<center>
                    {% for e in error %}
                        {{e}}
                    {% endfor %}
                </center>
				<h2>Configure Below Parameters</h2>

				<div>
                   <div>
                        <label for="MODEL_NAME"> Write model name you wnat for predication:</label>
						<input type="text" name="MODEL_NAME" id="MODEL_NAME" class="input-text" placeholder="MODEL_NAME" required>
					</div>
				</div>

				<div>
					<div>
                        <label for="PRED_TYPE"> Type of Predication :</label>
                         <select class="form-control custom_select" name="PRED_TYPE" id="PRED_TYPE">
                          <option value="Single Prediction">Single Prediction</option>
                          <option value="Mass Prediction">Mass Prediction</option>
                        </select>
					</div>
				</div>

			    <div class="form-row-last">
					<h1>Click Here To Predict !</h1>
					<input type="submit" name="register" class="register" value="Predict">
				</div>
			</form>
		</div>

	</div>

</body><!-- This templates was made by Colorlib (https://colorlib.com) -->
</html>


