<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<title>cv_image_suit</title>
	<!-- Mobile Specific Metas -->
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<!-- Font-->
	<link rel="stylesheet" type="text/css" href="static/css2/nunito-font.css">
	<!-- Main Style Css -->
    <link rel="stylesheet" href="static/css2/style.css"/>

</head>
<body class="form-v9">
	<div class="page-content">
		<div class="form-v9-content" style="background-image: url('static/assets/img/form-v9.jpg')">

			<form class="form-detail" action="/test" method="post">
				<h2>Experiment Results</h2>

				<div>
                   <div>
                        <label for="MODEL_NAME"> Best model :</label>
						<input type="text" name="MODEL_NAME" id="MODEL_NAME" class="input-text" placeholder="{{model_list['MODEL_OBJ']}}" disabled>
					</div>
				</div>

				<div>
                   <div>
                        <label for="IMAGE_SIZE"> Best image_size :</label>
						<input type="text" name="IMAGE_SIZE" id="IMAGE_SIZE" class="input-text" placeholder="{{model_list['IMAGE_SIZE']}}" disabled>
					</div>
				</div>

				<div>
                   <div>
                        <label for="BATCH_SIZE"> Best batch size :</label>
						<input type="text" name="BATCH_SIZE" id="BATCH_SIZE" class="input-text" placeholder="{{model_list['BATCH_SIZE']}}" disabled>
					</div>
				</div>

				<div>
                   <div>
                        <label for="OPTIMIZER"> Best optimizer :</label>
						<input type="text" name="OPTIMIZER" id="OPTIMIZER" class="input-text" placeholder="{{model_list['OPTIMIZER']}}" disabled>
					</div>
				</div>

				<div>
                   <div>
                        <label for="VAL_ACC"> Best validation accuracy :</label>
						<input type="text" name="VAL_ACC" id="VAL_ACC" class="input-text" placeholder="{{model_list['VAL_ACC']}}" disabled>
					</div>
				</div>

				<div class="form-row-last">
					<h1>Click Here To Download Results !</h1>
					<a href="/download" download style="color:white">Download</a>
				</div>
			</form>

		<form class="form-detail" action="/input3" method="get">

			<div class="form-row-last">
					<h1>See Experiment Logs Here!</h1>
					<input type="submit" name="log" class="register" value="Experiment Logs">
				</div>
			</form>

			<form class="form-detail" action="/" method="get">

			<div class="form-row-last">
					<input type="submit" name="log" class="register" value="Home">
				</div>
			</form>
		</div>

	</div>

<br>


</body><!-- This templates was made by Colorlib (https://colorlib.com) -->
</html>


