<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8">
	<title>cv_image_suit</title>
	<!-- Mobile Specific Metas -->
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<!-- Font-->
	<link rel="stylesheet" type="text/css" href="static/css2/nunito-font.css">
	<!-- Main Style Css -->
    <link rel="stylesheet" href="static/css2/style.css"/>

</head>
<body class="form-v9">
	<div class="page-content">
		<div class="form-v9-content" style="background-image: url('static/assets/img/form-v9.jpg')">

			<form class="form-detail" action="/explogs" method="post">
                 <center>
					<h2>Available Experiment Logs</h2>
                    {% for e in exps %}
                        {{e}}
                    {% endfor %}
                </center>

				<h2>Configure Below Parameters</h2>

				<div>
                   <div>
                        <label for="exp"> Write Experiment name :</label>
						<input type="text" name="exp" id="exp" class="input-text" placeholder="" required pattern="[A-Za-z0-9]+">
					</div>
				</div>

			    <div class="form-row-last">
					<h1>Click Here View Logs !</h1>
					<input type="submit" name="register" class="register" value="Experiment Logs">
				</div>
			</form>
		</div>

	</div>

</body><!-- This templates was made by Colorlib (https://colorlib.com) -->
</html>


