<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<title>cv_image_suit</title>
	<!-- Mobile Specific Metas -->
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
	<!-- Font-->
	<link rel="stylesheet" type="text/css" href="static/css2/nunito-font.css">
	<!-- Main Style Css -->
    <link rel="stylesheet" href="static/css2/style.css"/>
    <style>
        table{
            border:1px solid white;
        }
        tr{
            border:1px solid white;
        }
        h1,table{
            color:white;
            font-weight: bold;
        }
    </style>
</head>
<body class="form-v9"  style="background-image: url('static/assets/img/form-v9.jpg')">
            <center>
                <h1>Application Logs</h1>

                    <table border="1" align="center" width="80%">
                        <tr>
                            <td>Logs</td>
                        </tr>
                        {% for e in logs %}
                        <tr><td>{{e}}</td></tr>
                            {% endfor %}
                    </table>
                </center>
</body>
</html>